==============
django-userena
==============

Django userena's goal is to have a simple way to have full account management
for django application.

Visit the homepage_ for more information about django-userena.

.. _homepage: http://django-userena.org
